@@ -3,4 +3,4 @@
 from .RCR1000N import RCR1000N
 from .RCS1000N import RCS1000N
 
-__all__ = ['RCR1000N', 'RCS1000N']
+__all__ = ["RCR1000N", "RCS1000N"]
