@@ -2,4 +2,4 @@
 
 from .AB440SA import AB440SA
 
-__all__ = ['AB440SA']
+__all__ = ["AB440SA"]
