@@ -6,14 +6,14 @@ __instances = {}
 
 def singleton(cls):
     @wraps(cls)
-    def getInstance(*args, **kwargs):
+    def get_instance(*args, **kwargs):
         instance = __instances.get(cls, None)
         if not instance:
             instance = cls(*args, **kwargs)
             __instances[cls] = instance
         return instance
 
-    return getInstance
+    return get_instance
 
 
 def _delete_all_instances():
